@@ -1,11 +1,11 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 1d5fec0a2a294246711de0520f4a9a0331e8fe40 $
+// $Id: 212883e30353822903bf43521cf7d510bc580df6 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2000-2006 by Sergey Makovkin (CSDoom .62).
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -293,7 +293,7 @@ void M_Ticker(void);
 
 size_t P_NumPlayersInGame();
 void G_PlayerReborn (player_t &player);
-void P_KillMobj (AActor *source, AActor *target, AActor *inflictor, bool joinkill);
+void P_KillMobj (AActor *source, AActor *target, const AActor *inflictor, bool joinkill);
 void P_SetPsprite (player_t *player, int position, int32_t stnum);
 void P_ExplodeMissile (AActor* mo);
 void P_CalcHeight (player_t *player);
@@ -2178,7 +2178,7 @@ void CL_SendSummonFriendCheat(const char* summon)
 }
 
 
-void PickupMessage (AActor *toucher, const char *message)
+void PickupMessage (const AActor *toucher, const char *message)
 {
 	// Some maps have multiple items stacked on top of each other.
 	// It looks odd to display pickup messages for all of them.
@@ -2199,7 +2199,7 @@ void PickupMessage (AActor *toucher, const char *message)
 //
 // This is used for displaying weaponstay messages, it is inevitably a hack
 // because weaponstay is a hack
-void WeaponPickupMessage (AActor *toucher, weapontype_t &Weapon)
+void WeaponPickupMessage (const AActor *toucher, const weapontype_t &Weapon)
 {
     switch (Weapon)
     {
@@ -2476,4 +2476,4 @@ void SV_OnActivatedLine(line_t* line, AActor* mo, const int side,
 {
 }
 
-VERSION_CONTROL (cl_main_cpp, "$Id: 1d5fec0a2a294246711de0520f4a9a0331e8fe40 $")
+VERSION_CONTROL (cl_main_cpp, "$Id: 212883e30353822903bf43521cf7d510bc580df6 $")
