@@ -1,10 +1,10 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 5f75f7af610b2a8018f10624d2839a2fc8271764 $
+// $Id: 38065465ccabd39ad54ec16f66a0d3bddf015678 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -41,7 +41,7 @@
 #endif
 
 #include <cmath>
-
+#include <nonstd/scope.hpp>
 
 #include "m_alloc.h"
 #include "m_random.h"
@@ -602,62 +602,74 @@ EXTERN_CVAR(co_novileghosts)
 EXTERN_CVAR(co_removesoullimit)
 EXTERN_CVAR(co_allowdropoff)
 EXTERN_CVAR(r_clipmaskedspecial)
+EXTERN_CVAR(r_thingsectorlight)
 
 void G_ReadCOMPLVL()
 {
-	if (!serverside)
+	const int lumpnum = W_CheckNumForName("COMPLVL");
+	if (lumpnum == -1)
 		return;
 
-	int lumpnum = W_CheckNumForName("COMPLVL");
-	if (lumpnum != -1)
+	char* complvl = static_cast<char*>(W_CacheLumpNum(lumpnum, PU_STATIC));
+	auto guard = nonstd::make_scope_exit([&]{ Z_Free(complvl); });
+
+	if (!serverside)
 	{
-		char* complvl = static_cast<char*>(W_CacheLumpNum(lumpnum, PU_STATIC));
-
-		co_zdoomphys.Set(0.0f);
-		co_zdoomammo.Set(0.0f);
-
-		if (iequals("vanilla", complvl))
-		{
-			co_boomphys.Set(0.0f);
-			co_mbfphys.Set(0.0f);
-			co_novileghosts.Set(0.0f);
-			co_allowdropoff.Set(0.0f);
-			co_removesoullimit.Set(0.0f);
-			r_clipmaskedspecial.Set(0.0f);
-		}
-		else if (iequals("boom", complvl))
-		{
-			co_boomphys.Set(1.0f);
-			co_mbfphys.Set(0.0f);
-			co_novileghosts.Set(1.0f);
-			co_allowdropoff.Set(1.0f);
-			co_removesoullimit.Set(1.0f);
-			r_clipmaskedspecial.Set(0.0f);
-		}
-		else if (iequals("mbf", complvl))
-		{
-			co_boomphys.Set(1.0f);
-			co_mbfphys.Set(1.0f);
-			co_novileghosts.Set(1.0f);
-			co_allowdropoff.Set(1.0f);
-			co_removesoullimit.Set(1.0f);
-			r_clipmaskedspecial.Set(0.0f);
-		}
-		else if (iequals("mbf21", complvl))
-		{
-			co_boomphys.Set(1.0f);
-			co_mbfphys.Set(1.0f);
-			co_novileghosts.Set(1.0f);
-			co_allowdropoff.Set(1.0f);
-			co_removesoullimit.Set(1.0f);
-			r_clipmaskedspecial.Set(1.0f);
-		}
+		if (iequals("mbf", complvl))
+			r_thingsectorlight.Set(1.0f);
 		else
-		{
-			DPrintFmt("Unrecognized COMPLVL value: {}", complvl);
-		}
+			r_thingsectorlight.Set(0.0f);
 
-		Z_Free(complvl);
+		if (iequals("mbf21", complvl))
+			r_clipmaskedspecial.Set(1.0f);
+		else
+			r_clipmaskedspecial.Set(0.0f);
+
+		return;
+	}
+
+	co_zdoomphys.Set(0.0f);
+	co_zdoomammo.Set(0.0f);
+
+	if (iequals("vanilla", complvl))
+	{
+		co_boomphys.Set(0.0f);
+		co_mbfphys.Set(0.0f);
+		co_novileghosts.Set(0.0f);
+		co_allowdropoff.Set(0.0f);
+		co_removesoullimit.Set(0.0f);
+		r_clipmaskedspecial.Set(0.0f);
+	}
+	else if (iequals("boom", complvl))
+	{
+		co_boomphys.Set(1.0f);
+		co_mbfphys.Set(0.0f);
+		co_novileghosts.Set(1.0f);
+		co_allowdropoff.Set(1.0f);
+		co_removesoullimit.Set(1.0f);
+		r_clipmaskedspecial.Set(0.0f);
+	}
+	else if (iequals("mbf", complvl))
+	{
+		co_boomphys.Set(1.0f);
+		co_mbfphys.Set(1.0f);
+		co_novileghosts.Set(1.0f);
+		co_allowdropoff.Set(1.0f);
+		co_removesoullimit.Set(1.0f);
+		r_clipmaskedspecial.Set(0.0f);
+	}
+	else if (iequals("mbf21", complvl))
+	{
+		co_boomphys.Set(1.0f);
+		co_mbfphys.Set(1.0f);
+		co_novileghosts.Set(1.0f);
+		co_allowdropoff.Set(1.0f);
+		co_removesoullimit.Set(1.0f);
+		r_clipmaskedspecial.Set(1.0f);
+	}
+	else
+	{
+		DPrintFmt("Unrecognized COMPLVL value: {}", complvl);
 	}
 }
 
@@ -1120,4 +1132,4 @@ void D_DoomMain()
 	D_DoomLoop();		// never returns
 }
 
-VERSION_CONTROL (d_main_cpp, "$Id: 5f75f7af610b2a8018f10624d2839a2fc8271764 $")
+VERSION_CONTROL (d_main_cpp, "$Id: 38065465ccabd39ad54ec16f66a0d3bddf015678 $")
