@@ -1,10 +1,10 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 4b91ae9b6bbd3d95b1d522eb6e4a34554d5e52b7 $
+// $Id: 0f742e9fa1b699581cf25343686c1f9feb34ea7c $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -57,8 +57,8 @@ static constexpr fixed_t S_STEREO_SWING = 96 * FRACUNIT;
 struct channel_t
 {
 public:
-	fixed_t*	pt;				// origin of sound
-	fixed_t		x, y;			// origin if pt is NULL
+	const fixed_t*	pt;				// origin of sound
+	fixed_t		x, y;			// origin if pt is nullptr
 	sfxinfo_t*	sfxinfo;		// sound information (if null, channel avail.)
 	int 		handle;			// handle of the sound being played
 	int			sound_id;
@@ -74,9 +74,9 @@ public:
 
 	void clear()
 	{
-		pt = NULL;
+		pt = nullptr;
 		x = y = 0;
-		sfxinfo = NULL;
+		sfxinfo = nullptr;
 		handle = -1;
 		sound_id = -1;
 		entchannel = CHAN_VOICE;
@@ -169,7 +169,7 @@ void S_NoiseDebug()
 		if (Channel[i].sfxinfo)
 		{
 			char temp[16];
-			fixed_t *origin = Channel[i].pt;
+			const fixed_t *origin = Channel[i].pt;
 
 			if (Channel[i].attenuation == ATTN_NONE && listenplayer().camera)
 			{
@@ -278,8 +278,8 @@ void S_Init(float sfxVolume, float musicVolume)
  */
 void S_Deinit()
 {
-	::SoundCurve = NULL;
-	::Channel = NULL;
+	::SoundCurve = nullptr;
+	::Channel = nullptr;
 }
 
 //
@@ -358,7 +358,7 @@ int S_GetChannel(sfxinfo_t* sfxinfo, float volume, int priority, unsigned max_in
                  fixed_t dist, int channel)
 {
 	// not a valid sound
-	if (::Channel == NULL || sfxinfo == NULL)
+	if (::Channel == nullptr || sfxinfo == nullptr)
 		return -1;
 
 	// Sort the sound channels by descending priority levels
@@ -388,7 +388,7 @@ int S_GetChannel(sfxinfo_t* sfxinfo, float volume, int priority, unsigned max_in
 
 	// try to find the first empty channel
 	for (size_t i = 0; i < numChannels; i++)
-		if (Channel[i].sfxinfo == NULL)
+		if (Channel[i].sfxinfo == nullptr)
 			return i;
 
 	// No empty channels and this is an ambient sound?
@@ -603,13 +603,64 @@ static int ResolveSound(int soundid)
 	return sfx.link;
 }
 
+class sound_origin_t
+{
+	enum
+	{
+		StaticPoint,
+		MoveablePoint,
+		Entity
+	} type;
+
+	union {
+		const fixed_t* pt;
+		const AActor* ent;
+		struct {
+			fixed_t x, y;
+		};
+	};
+
+public:
+	sound_origin_t() noexcept: type(StaticPoint), x(0), y(0) {}
+	explicit sound_origin_t(fixed_t _x, fixed_t _y) noexcept: type(StaticPoint), x(_x), y(_y) {}
+	explicit sound_origin_t(const fixed_t* _pt) noexcept: type(MoveablePoint), pt(_pt) {}
+	explicit sound_origin_t(const AActor* _ent) noexcept: type(Entity), ent(_ent) {}
+
+	[[nodiscard]] std::tuple<const fixed_t*, fixed_t, fixed_t> get_point() noexcept
+	{
+		switch (type)
+		{
+			case sound_origin_t::MoveablePoint:
+				if (pt == nullptr)
+					return { nullptr, 0, 0 };
+				else
+					return { pt, pt[0], pt[1] };
+			case sound_origin_t::StaticPoint:
+				return { nullptr, x, y };
+			case sound_origin_t::Entity:
+				if (ent == nullptr)
+					return { nullptr, 0, 0 };
+				else
+					return { &ent->x, ent->x, ent->y };
+		}
+	}
+
+	[[nodiscard]] const AActor* get_entity() noexcept
+	{
+		if (type == Entity)
+			return ent;
+		else
+			return nullptr;
+	}
+};
+
 //
 // S_StartSound
 //
 // joek - choco's S_StartSoundAtVolume with some zdoom code
 // a bit of a whore of a funtion but she works ok
 //
-static void S_StartSound(fixed_t* pt, fixed_t x, fixed_t y, int channel,
+static void S_StartSound(sound_origin_t origin, int channel,
 	                     int sfx_id, float volume, int attenuation, bool looping,
 	                     float dist_scale = 0.0f)
 {
@@ -651,15 +702,7 @@ static void S_StartSound(fixed_t* pt, fixed_t x, fixed_t y, int channel,
 		return;
 	}
 
-	if (pt == (fixed_t *)(~0))
-	{
-		pt = NULL;
-	}
-	else if (pt != NULL)
-	{
-		x = pt[0];
-		y = pt[1];
-	}
+	const auto& [pt, x, y] = origin.get_point();
 
 	if (sfxinfo->lumpnum == sfx_empty)
 		return;
@@ -746,15 +789,15 @@ static void S_StartSound(fixed_t* pt, fixed_t x, fixed_t y, int channel,
 
 void S_SoundID(int channel, int sound_id, float volume, int attenuation)
 {
-	S_StartSound((fixed_t *)NULL, 0, 0, channel, sound_id, volume, attenuation, false);
+	S_StartSound(sound_origin_t(), channel, sound_id, volume, attenuation, false);
 }
 
 void S_SoundID(fixed_t x, fixed_t y, int channel, int sound_id, float volume, int attenuation)
 {
-	S_StartSound((fixed_t *)NULL, x, y, channel, sound_id, volume, attenuation, false);
+	S_StartSound(sound_origin_t(x, y), channel, sound_id, volume, attenuation, false);
 }
 
-void S_SoundID(AActor *ent, int channel, int sound_id, float volume, int attenuation)
+void S_SoundID(const AActor *ent, int channel, int sound_id, float volume, int attenuation)
 {
 	if (!ent)
 		return;
@@ -762,15 +805,15 @@ void S_SoundID(AActor *ent, int channel, int sound_id, float volume, int attenua
 	if (ent->subsector && ent->subsector->sector &&
 		ent->subsector->sector->MoreFlags & SECF_SILENT)
 		return;
-	S_StartSound (&ent->x, 0, 0, channel, sound_id, volume, attenuation, false);
+	S_StartSound(sound_origin_t(&ent->x), channel, sound_id, volume, attenuation, false);
 }
 
-void S_SoundID(fixed_t *pt, int channel, int sound_id, float volume, int attenuation)
+void S_SoundID(const fixed_t *pt, int channel, int sound_id, float volume, int attenuation)
 {
-	S_StartSound(pt, 0, 0, channel, sound_id, volume, attenuation, false);
+	S_StartSound(sound_origin_t(pt), channel, sound_id, volume, attenuation, false);
 }
 
-void S_LoopedSoundID(AActor *ent, int channel, int sound_id, float volume, int attenuation)
+void S_LoopedSoundID(const AActor *ent, int channel, int sound_id, float volume, int attenuation)
 {
 	if (!ent)
 		return;
@@ -778,15 +821,16 @@ void S_LoopedSoundID(AActor *ent, int channel, int sound_id, float volume, int a
 	if (ent->subsector && ent->subsector->sector &&
 		ent->subsector->sector->MoreFlags & SECF_SILENT)
 		return;
-	S_StartSound(&ent->x, 0, 0, channel, sound_id, volume, attenuation, true);
+
+	S_StartSound(sound_origin_t(&ent->x), channel, sound_id, volume, attenuation, true);
 }
 
-void S_LoopedSoundID(fixed_t *pt, int channel, int sound_id, float volume, int attenuation)
+void S_LoopedSoundID(const fixed_t *pt, int channel, int sound_id, float volume, int attenuation)
 {
-	S_StartSound(pt, 0, 0, channel, sound_id, volume, attenuation, true);
+	S_StartSound(sound_origin_t(pt), channel, sound_id, volume, attenuation, true);
 }
 
-int S_FindGenderedSound(std::string_view name, AActor* ent)
+int S_FindGenderedSound(std::string_view name, const AActor* ent)
 {
 	static constexpr std::string_view templat = "player/{}/{}";
 	// static constexpr std::string_view genders[] = { "male", "female", "cyborg", "other" };
@@ -794,7 +838,7 @@ int S_FindGenderedSound(std::string_view name, AActor* ent)
 	player_t *player;
 
 	int sfx_id = -1;
-	if (ent && ent != (AActor *)(~0) && (player = ent->player))
+	if (ent && (player = ent->player))
 	{
 		sfx_id = S_FindSound(fmt::format(templat, "base", name).c_str());
 		if (sfx_id == -1)
@@ -809,7 +853,7 @@ int S_FindGenderedSound(std::string_view name, AActor* ent)
 	return sfx_id;
 }
 
-static void S_StartNamedSound(AActor *ent, fixed_t *pt, fixed_t x, fixed_t y, int channel,
+static void S_StartNamedSound(sound_origin_t origin, int channel,
                               const char *name, float volume, int attenuation, bool looping,
                               float dist_scale = 0.0f)
 {
@@ -818,19 +862,18 @@ static void S_StartNamedSound(AActor *ent, fixed_t *pt, fixed_t x, fixed_t y, in
 
 	const std::string soundname = name ? name : "";
 
-	if (soundname.empty() ||
-			(ent && ent != (AActor *)(~0) && ent->subsector && ent->subsector->sector &&
-			ent->subsector->sector->MoreFlags & SECF_SILENT))
-	{
+	if (soundname.empty())
+		return;
+
+	const AActor* ent = origin.get_entity();
+	if (ent && ent->subsector && ent->subsector->sector &&
+	    ent->subsector->sector->MoreFlags & SECF_SILENT)
 		return;
-	}
 
 	int sfx_id = -1;
 
 	if (soundname[0] == '*')
-	{
 		sfx_id = S_FindGenderedSound(soundname.substr(1), ent);
-	}
 	else
 		sfx_id = S_FindSound(soundname.c_str());
 
@@ -840,19 +883,14 @@ static void S_StartNamedSound(AActor *ent, fixed_t *pt, fixed_t x, fixed_t y, in
 		return;
 	}
 
-	if (ent && ent != (AActor *)(~0))
-		S_StartSound(&ent->x, x, y, channel, sfx_id, volume, attenuation, looping, dist_scale);
-	else if (pt)
-		S_StartSound(pt, x, y, channel, sfx_id, volume, attenuation, looping, dist_scale);
-	else
-		S_StartSound((fixed_t *)ent, x, y, channel, sfx_id, volume, attenuation, looping, dist_scale);
+	S_StartSound(origin, channel, sfx_id, volume, attenuation, looping, dist_scale);
 }
 
 // [Russell] - Hack to stop multiple plat stop sounds
 void S_PlatSound(fixed_t *pt, int channel, const char *name, float volume, int attenuation)
 {
     if (!predicting)
-        S_StartNamedSound(NULL, pt, 0, 0, channel, name, volume, attenuation, false);
+        S_StartNamedSound(sound_origin_t(pt), channel, name, volume, attenuation, false);
 }
 
 void S_Sound(int channel, const char *name, float volume, int attenuation)
@@ -860,35 +898,35 @@ void S_Sound(int channel, const char *name, float volume, int attenuation)
 	// [SL] 2011-05-27 - This particular S_Sound() function is only used for sounds
 	// that should be full volume regardless of location.  Ignore the specified
 	// attenuation and use ATTN_NONE instead.
-	S_StartNamedSound((AActor *)NULL, NULL, 0, 0, channel, name, volume, ATTN_NONE, false);
+	S_StartNamedSound(sound_origin_t(), channel, name, volume, ATTN_NONE, false);
 }
 
-void S_Sound(AActor *ent, int channel, const char *name, float volume, int attenuation)
+void S_Sound(const AActor *ent, int channel, const char *name, float volume, int attenuation)
 {
 	if(!co_globalsound && channel == CHAN_ITEM && ent != listenplayer().camera)
 		return;
 
-	S_StartNamedSound(ent, NULL, 0, 0, channel, name, volume, attenuation, false);
+	S_StartNamedSound(sound_origin_t(ent), channel, name, volume, attenuation, false);
 }
 
-void S_Sound(fixed_t *pt, int channel, const char *name, float volume, int attenuation)
+void S_Sound(const fixed_t *pt, int channel, const char *name, float volume, int attenuation)
 {
-	S_StartNamedSound(NULL, pt, 0, 0, channel, name, volume, attenuation, false);
+	S_StartNamedSound(sound_origin_t(pt), channel, name, volume, attenuation, false);
 }
 
-void S_LoopedSound(AActor *ent, int channel, const char *name, float volume, int attenuation)
+void S_LoopedSound(const AActor *ent, int channel, const char *name, float volume, int attenuation)
 {
-	S_StartNamedSound(ent, NULL, 0, 0, channel, name, volume, attenuation, true);
+	S_StartNamedSound(sound_origin_t(ent), channel, name, volume, attenuation, true);
 }
 
-void S_LoopedSound(fixed_t *pt, int channel, const char *name, float volume, int attenuation)
+void S_LoopedSound(const fixed_t *pt, int channel, const char *name, float volume, int attenuation)
 {
-	S_StartNamedSound(NULL, pt, 0, 0, channel, name, volume, attenuation, true);
+	S_StartNamedSound(sound_origin_t(pt), channel, name, volume, attenuation, true);
 }
 
 void S_Sound(fixed_t x, fixed_t y, int channel, const char *name, float volume, int attenuation)
 {
-	S_StartNamedSound((AActor *)(~0), NULL, x, y, channel, name, volume, attenuation, false);
+	S_StartNamedSound(sound_origin_t(x, y), channel, name, volume, attenuation, false);
 }
 
 
@@ -897,7 +935,7 @@ void S_Sound(fixed_t x, fixed_t y, int channel, const char *name, float volume,
 //
 static void S_StopChannel(unsigned int cnum)
 {
-	if (::Channel == NULL)
+	if (::Channel == nullptr)
 		return;
 
 	if (cnum >= numChannels)
@@ -915,7 +953,7 @@ static void S_StopChannel(unsigned int cnum)
 }
 
 
-void S_StopSound(fixed_t *pt)
+void S_StopSound(const fixed_t *pt)
 {
 	for (unsigned int i = 0; i < numChannels; i++)
 		if (Channel[i].sfxinfo && (Channel[i].pt == pt))
@@ -924,9 +962,9 @@ void S_StopSound(fixed_t *pt)
 		}
 }
 
-void S_StopSound(fixed_t *pt, int channel)
+void S_StopSound(const fixed_t *pt, int channel)
 {
-	if (::Channel == NULL)
+	if (::Channel == nullptr)
 		return;
 
 	for (unsigned int i = 0; i < numChannels; i++)
@@ -936,7 +974,7 @@ void S_StopSound(fixed_t *pt, int channel)
 			S_StopChannel(i);
 }
 
-void S_StopSound(AActor *ent, int channel)
+void S_StopSound(const AActor *ent, int channel)
 {
 	S_StopSound(&ent->x, channel);
 }
@@ -990,17 +1028,17 @@ void S_ResumeSound()
 
 
 // Moves all the sounds from one thing to another. If the destination is
-// NULL, then the sound becomes a positioned sound.
-void S_RelinkSound(AActor *from, AActor *to)
+// nullptr, then the sound becomes a positioned sound.
+void S_RelinkSound(const AActor *from, const AActor *to)
 {
-	if (::Channel == NULL)
+	if (::Channel == nullptr)
 		return;
 
 	if (!from)
 		return;
 
 	const fixed_t *frompt = &from->x;
-	fixed_t *topt = to ? &to->x : NULL;
+	const fixed_t *topt = to ? &to->x : nullptr;
 
 	for (unsigned int i = 0; i < numChannels; i++)
 	{
@@ -1013,7 +1051,7 @@ void S_RelinkSound(AActor *from, AActor *to)
 	}
 }
 
-bool S_GetSoundPlayingInfo(fixed_t *pt, int sound_id)
+bool S_GetSoundPlayingInfo(const fixed_t *pt, int sound_id)
 {
 	for (unsigned int i = 0; i < numChannels; i++)
 	{
@@ -1023,9 +1061,9 @@ bool S_GetSoundPlayingInfo(fixed_t *pt, int sound_id)
 	return false;
 }
 
-bool S_GetSoundPlayingInfo(AActor *ent, int sound_id)
+bool S_GetSoundPlayingInfo(const AActor *ent, int sound_id)
 {
-	return S_GetSoundPlayingInfo (ent ? &ent->x : NULL, sound_id);
+	return S_GetSoundPlayingInfo (ent ? &ent->x : nullptr, sound_id);
 }
 
 //
@@ -1053,12 +1091,11 @@ void S_ResumeMusic()
 // Updates music & sounds
 //
 // joek - from choco again
-void S_UpdateSounds(void* listener_p)
+void S_UpdateSounds(const AActor* listener)
 {
-	if (::Channel == NULL)
+	if (::Channel == nullptr)
 		return;
 
-	AActor* listener = (AActor*)listener_p;
 	for (int cnum = 0; cnum < (int)numChannels; cnum++)
 	{
 		channel_t* c = &Channel[cnum];
@@ -1179,7 +1216,7 @@ void S_ChangeMusic(std::string musicname, bool looping, int order)
 		return;
 	}
 
-	byte* data = NULL;
+	byte* data = nullptr;
 	size_t length = 0;
 	FILE *f;
 
@@ -1267,7 +1304,7 @@ void A_Ambient(AActor *actor)
 		{
 			const int attn_type =
 			    (ambient->type == amb_type_t::POINT ? ATTN_IDLE : ATTN_NONE);
-			S_StartNamedSound(actor, NULL, 0, 0, CHAN_AMBIENT, ambient->sound,
+			S_StartNamedSound(sound_origin_t(actor), CHAN_AMBIENT, ambient->sound,
 			                  ambient->volume, attn_type, true, ambient->attenuation);
 
 			SetTicker (&actor->tics, ambient);
@@ -1283,7 +1320,7 @@ void A_Ambient(AActor *actor)
 		{
 			const int attn_type =
 			    (ambient->type == amb_type_t::POINT ? ATTN_IDLE : ATTN_NONE);
-			S_StartNamedSound(actor, NULL, 0, 0, CHAN_AMBIENT, ambient->sound,
+			S_StartNamedSound(sound_origin_t(actor), CHAN_AMBIENT, ambient->sound,
 			                  ambient->volume, attn_type, false, ambient->attenuation);
 
 			SetTicker (&actor->tics, ambient);
@@ -1384,9 +1421,9 @@ END_COMMAND (changemus)
 // UV_SoundAvoidCl
 // Sends a sound to clients, but doesn't send it to client 'player'.
 //
-void UV_SoundAvoidPlayer(AActor *mo, byte channel, const char *name, byte attenuation)
+void UV_SoundAvoidPlayer(const AActor *mo, byte channel, const char *name, byte attenuation)
 {
 	S_Sound(mo, channel, name, 1, attenuation);
 }
 
-VERSION_CONTROL (s_sound_cpp, "$Id: 4b91ae9b6bbd3d95b1d522eb6e4a34554d5e52b7 $")
+VERSION_CONTROL (s_sound_cpp, "$Id: 0f742e9fa1b699581cf25343686c1f9feb34ea7c $")
