@@ -25,7 +25,6 @@
 #include "farchive.h"
 #include "gi.h"
 #include "g_game.h"
-#include "huffman.h"
 #include "info.h"
 #include "i_net.h"
 #include "i_system.h"
@@ -74,7 +73,6 @@
 #include "s_sndseq.h"
 #include "s_sound.h"
 #include "tables.h"
-#include "tarray.h"
 #include "m_vectors.h"
 #include "v_palette.h"
 #include "v_video.h"
