@@ -1,10 +1,10 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: a21c26e7c19feb748e1725b179074a6bf48aad30 $
+// $Id: f0608c53c5c96a864a784a92ecba6a37d710d7df $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -799,7 +799,8 @@ static void ReplaceSpecialChars(std::string& str)
 		{
 			*write++ = c;
 		}
-		else
+		// don't read past a trailing backslash
+		else if (*read)
 		{
 			switch (*read)
 			{
@@ -2133,18 +2134,14 @@ static void PatchStrings(int dummy, DehScanner& scanner)
 		int i = GStrings.toIndex(key);
 		if (iequals("DEHTHING_", key.substr(0, 9)))
 		{
-			try {
-				int32_t type = ParseNum<int32_t>(string).value_or(0);
-				type--;
-				P_MapDehThing(static_cast<mobjtype_t>(type), std::string(key)); // TODO: rework so no casting needed
+			if (auto type = ParseNum<int32_t>(string))
+			{
+				(*type)--;
+				P_MapDehThing(static_cast<mobjtype_t>(*type), std::string(key)); // TODO: rework so no casting needed
 				GStrings.setString(key, string);
 				DPrintFmt("{} set to:\n{}\n", key, string);
 			}
-			catch (const std::invalid_argument&)
-			{
-				PrintFmt(PRINT_HIGH, "Invalid thing type {} for {}\n", string, key);
-			}
-			catch (const std::out_of_range&)
+			else
 			{
 				PrintFmt(PRINT_HIGH, "Invalid thing type {} for {}\n", string, key);
 			}
@@ -2755,4 +2752,4 @@ BEGIN_COMMAND(playstate)
 }
 END_COMMAND(playstate)
 
-VERSION_CONTROL(d_dehacked_cpp, "$Id: a21c26e7c19feb748e1725b179074a6bf48aad30 $")
+VERSION_CONTROL(d_dehacked_cpp, "$Id: f0608c53c5c96a864a784a92ecba6a37d710d7df $")
