@@ -1,10 +1,10 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 12169a1cfff9e71c5258b483fd13be9b98ac6b7f $
+// $Id: 2867381ec213f51000a3335c3c448f6aeb11f072 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -1562,7 +1562,7 @@ int DLevelScript::CountPlayers()
 	return static_cast<int>(P_NumPlayersInGame());
 }
 
-void DLevelScript::ACS_SetLineTexture(int* args, byte argCount)
+void DLevelScript::ACS_SetLineTexture(const int* args, byte argCount)
 {
 	if (argCount < 4)
 		return;
@@ -1591,7 +1591,7 @@ void DLevelScript::ACS_Print(byte pcd, AActor* activator, const char* print)
 	}
 }
 
-void DLevelScript::ACS_ChangeMusic(byte pcd, AActor* activator, int* args, byte argCount)
+void DLevelScript::ACS_ChangeMusic(byte pcd, const AActor* activator, const int* args, byte argCount)
 {
 	if (argCount < 2)
 		return;
@@ -1599,7 +1599,7 @@ void DLevelScript::ACS_ChangeMusic(byte pcd, AActor* activator, int* args, byte
 	ChangeMusic(pcd, activator, args[0], args[1]);
 }
 
-void DLevelScript::ACS_StartSound(byte pcd, AActor* activator, int* args, byte argCount)
+void DLevelScript::ACS_StartSound(byte pcd, const AActor* activator, const int* args, byte argCount)
 {
 	if (pcd == PCD_SECTORSOUND)
 	{
@@ -1626,7 +1626,7 @@ void DLevelScript::ACS_StartSound(byte pcd, AActor* activator, int* args, byte a
 	}
 }
 
-void DLevelScript::ACS_SetLineBlocking(int* args, byte argCount)
+void DLevelScript::ACS_SetLineBlocking(const int* args, byte argCount)
 {
 	if (argCount < 2)
 		return;
@@ -1634,7 +1634,7 @@ void DLevelScript::ACS_SetLineBlocking(int* args, byte argCount)
 	SetLineBlocking(args[0], args[1]);
 }
 
-void DLevelScript::ACS_SetLineMonsterBlocking(int* args, byte argCount)
+void DLevelScript::ACS_SetLineMonsterBlocking(const int* args, byte argCount)
 {
 	if (argCount < 2)
 		return;
@@ -1642,7 +1642,7 @@ void DLevelScript::ACS_SetLineMonsterBlocking(int* args, byte argCount)
 	SetLineMonsterBlocking(args[0], args[1]);
 }
 
-void DLevelScript::ACS_SetLineSpecial(int* args, byte argCount)
+void DLevelScript::ACS_SetLineSpecial(const int* args, byte argCount)
 {
 	if (argCount < 7)
 		return;
@@ -1650,7 +1650,7 @@ void DLevelScript::ACS_SetLineSpecial(int* args, byte argCount)
 	SetLineSpecial(args[0], args[1], args[2], args[3], args[4], args[5], args[6]);
 }
 
-void DLevelScript::ACS_SetThingSpecial(int* args, byte argCount)
+void DLevelScript::ACS_SetThingSpecial(const int* args, byte argCount)
 {
 	if (argCount < 7)
 		return;
@@ -1660,7 +1660,7 @@ void DLevelScript::ACS_SetThingSpecial(int* args, byte argCount)
 		SetThingSpecial(actor, args[1], args[2], args[3], args[4], args[5], args[6]);
 }
 
-void DLevelScript::ACS_FadeRange(AActor* activator, int* args, byte argCount)
+void DLevelScript::ACS_FadeRange(AActor* activator, const int* args, byte argCount)
 {
 	if (argCount < 9)
 		return;
@@ -1673,7 +1673,7 @@ void DLevelScript::ACS_CancelFade(AActor* actor)
 	CancelFade(actor);
 }
 
-void DLevelScript::ACS_ChangeFlat(byte pcd, int* args, byte argCount)
+void DLevelScript::ACS_ChangeFlat(byte pcd, const int* args, byte argCount)
 {
 	if (argCount < 2)
 		return;
@@ -1681,7 +1681,7 @@ void DLevelScript::ACS_ChangeFlat(byte pcd, int* args, byte argCount)
 	ChangeFlat(args[0], args[1], pcd == PCD_CHANGECEILING);
 }
 
-void DLevelScript::ACS_SoundSequence(int* args, byte argCount)
+void DLevelScript::ACS_SoundSequence(const int* args, byte argCount)
 {
 	if (argCount < 2)
 		return;
@@ -1831,7 +1831,7 @@ void DLevelScript::ActivateLineSpecial(byte special, line_t* line, AActor* activ
 	}
 }
 
-void DLevelScript::ChangeMusic(byte pcd, AActor* activator, int index, int loop)
+void DLevelScript::ChangeMusic(byte pcd, const AActor* activator, int index, int loop)
 {
 	bool local = (pcd == PCD_LOCALSETMUSIC || pcd == PCD_LOCALSETMUSICDIRECT);
 
@@ -1854,7 +1854,7 @@ void DLevelScript::ChangeMusic(byte pcd, AActor* activator, int index, int loop)
 }
 
 
-void DLevelScript::StartSound(byte pcd, AActor* activator, int channel, int index, int volume, int attenuation)
+void DLevelScript::StartSound(byte pcd, const AActor* activator, int channel, int index, int volume, int attenuation)
 {
 	bool local = pcd == PCD_LOCALAMBIENTSOUND;
 
@@ -1876,7 +1876,7 @@ void DLevelScript::StartSound(byte pcd, AActor* activator, int channel, int inde
 	}
 }
 
-void DLevelScript::StartSectorSound(byte pcd, sector_t* sector, int channel, int index, int volume, int attenuation)
+void DLevelScript::StartSectorSound(byte pcd, const sector_t* sector, int channel, int index, int volume, int attenuation)
 {
 	if (clientside)
 	{
@@ -1894,7 +1894,7 @@ void DLevelScript::StartSectorSound(byte pcd, sector_t* sector, int channel, int
 	}
 }
 
-void DLevelScript::StartThingSound(byte pcd, AActor* actor, int channel, int index, int volume, int attenuation)
+void DLevelScript::StartThingSound(byte pcd, const AActor* actor, int channel, int index, int volume, int attenuation)
 {
 	if (clientside)
 	{
@@ -4078,7 +4078,7 @@ void strbin (char *str)
 	while ( (c = *p++) ) {
 		if (c != '\\') {
 			*str++ = c;
-		} else {
+		} else if (*p) {
 			switch (*p) {
 				case 'c':
 					*str++ = '\034';	// TEXTCOLOR_ESCAPE
@@ -4211,4 +4211,4 @@ void DACSThinker::DumpScriptStatus ()
 }
 
 
-VERSION_CONTROL (p_acs_cpp, "$Id: 12169a1cfff9e71c5258b483fd13be9b98ac6b7f $")
+VERSION_CONTROL (p_acs_cpp, "$Id: 2867381ec213f51000a3335c3c448f6aeb11f072 $")
