@@ -1,10 +1,10 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: a0f17f0b8d49972611284db7648b19ad698d6611 $
+// $Id: 72d8632d855fde80bbbe53c7935f38a30c3eda3f $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -575,7 +575,7 @@ DDoor* DDoor::Clone(sector_t* sec) const
 	return door;
 }
 
-bool EV_DoDoor (DDoor::EVlDoor type, line_t *line, AActor *thing,
+bool EV_DoDoor (DDoor::EVlDoor type, line_t *line, const AActor *thing,
                 int tag, int speed, int delay, card_t lock)
 {
 	bool		rtn = false;
@@ -968,4 +968,4 @@ manual_genlocked:
 }
 
 
-VERSION_CONTROL (p_doors_cpp, "$Id: a0f17f0b8d49972611284db7648b19ad698d6611 $")
+VERSION_CONTROL (p_doors_cpp, "$Id: 72d8632d855fde80bbbe53c7935f38a30c3eda3f $")
