@@ -1,10 +1,10 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: c787f35f5cff57785896df08199d0be84e51227a $
+// $Id: e87244faf314ad61935bb737dafbf420c06dc3cf $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -112,9 +112,9 @@ void A_Fall (AActor *actor);
 
 
 void SV_UpdateMonsterRespawnCount();
-void SV_SendRaiseMobj(AActor* source, AActor* corpse);
-void SV_UpdateMobj(AActor* mo);
-void SV_Sound(AActor* mo, byte channel, const char* name, byte attenuation);
+void SV_SendRaiseMobj(const AActor* source, const AActor* corpse);
+void SV_UpdateMobj(const AActor* mo);
+void SV_Sound(const AActor* mo, byte channel, const char* name, byte attenuation);
 void SV_SpawnMobj(AActor* mobj);
 
 extern bool isFast;
@@ -4006,4 +4006,4 @@ void A_LineEffect(AActor* mo)
 	}
 }
 
-VERSION_CONTROL (p_enemy_cpp, "$Id: c787f35f5cff57785896df08199d0be84e51227a $")
+VERSION_CONTROL (p_enemy_cpp, "$Id: e87244faf314ad61935bb737dafbf420c06dc3cf $")
