@@ -1,10 +1,10 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 48bbc8fbb9cc5f8ab650fa4bdea27efbf0d29cc4 $
+// $Id: c34bbc2f99c7b43860601d37b228646805df1c89 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -83,22 +83,22 @@ void AM_Stop(void);
 void SV_SpawnMobj(AActor *mobj);
 void SV_UpdateFrags(player_t &player);
 void SV_CTFEvent(team_t f, flag_score_t event, player_t &who);
-void SV_TouchSpecial(AActor *special, player_t *player);
+void SV_TouchSpecial(const AActor *special, player_t *player);
 ItemEquipVal SV_FlagTouch(player_t &player, team_t f, bool firstgrab);
 void SV_SocketTouch(player_t &player, team_t f);
-void SV_SendKillMobj(AActor *source, AActor *target, AActor *inflictor, bool joinkill);
-void SV_SendDamagePlayer(player_t *player, AActor* inflictor, int healthDamage, int armorDamage);
-void SV_SendDamageMobj(AActor *target, int pain);
-void SV_UpdateMobj(AActor* mo);
-void SV_ActorTarget(AActor *actor);
-void PickupMessage(AActor *toucher, const char *message);
-void WeaponPickupMessage(AActor *toucher, weapontype_t &Weapon);
+void SV_SendKillMobj(const AActor *source, const AActor *target, const AActor *inflictor, bool joinkill);
+void SV_SendDamagePlayer(player_t *player, const AActor* inflictor, int healthDamage, int armorDamage);
+void SV_SendDamageMobj(const AActor *target, int pain);
+void SV_UpdateMobj(const AActor* mo);
+void SV_ActorTarget(const AActor *actor);
+void PickupMessage(const AActor *toucher, const char *message);
+void WeaponPickupMessage(const AActor *toucher, const weapontype_t &Weapon);
 
 #ifdef SERVER_APP
-void SV_ShareKeys(card_t card, player_t& player);
+void SV_ShareKeys(card_t card, const player_t& player);
 #endif
 
-static void PersistPlayerDamage(player_t& p)
+static void PersistPlayerDamage(const player_t& p)
 {
 	// Send this information to everybody.
 	for (auto& player : ::players)
@@ -855,7 +855,7 @@ static void P_GiveCarePack(player_t* player)
 	}
 }
 
-bool P_SpecialIsWeapon(AActor *special)
+bool P_SpecialIsWeapon(const AActor *special)
 {
 	if (!special)
 		return false;
@@ -1481,7 +1481,7 @@ void SexMessage (const char *from, char *to, gender_t gender, std::string_view v
 // [RH]
 // ClientObituary: Show a message when a player dies
 //
-static void ClientObituary(AActor* self, AActor* inflictor, AActor* attacker)
+static void ClientObituary(AActor* self, const AActor* inflictor, AActor* attacker)
 {
 	char gendermessage[1024];
 
@@ -1772,7 +1772,7 @@ static void ClientObituary(AActor* self, AActor* inflictor, AActor* attacker)
 //
 // P_KillMobj
 //
-void P_KillMobj(AActor *source, AActor *target, AActor *inflictor, bool joinkill)
+void P_KillMobj(AActor *source, AActor *target, const AActor *inflictor, bool joinkill)
 {
 	SV_SendKillMobj(source, target, inflictor, joinkill);
 	AActor *mo;
@@ -2109,7 +2109,7 @@ bool P_InfightingImmune(AActor* target, AActor* source)
 // and other environmental stuff.
 //
 // [Toke] This is no longer needed client-side
-void P_DamageMobj(AActor *target, AActor *inflictor, AActor *source, int damage, int mod, int flags)
+void P_DamageMobj(AActor *target, const AActor *inflictor, AActor *source, int damage, int mod, int flags)
 {
 	if (!serverside)
     {
@@ -2578,4 +2578,4 @@ void P_HealMobj(AActor* mo, int num)
 	}
 }
 
-VERSION_CONTROL (p_interaction_cpp, "$Id: 48bbc8fbb9cc5f8ab650fa4bdea27efbf0d29cc4 $")
+VERSION_CONTROL (p_interaction_cpp, "$Id: c34bbc2f99c7b43860601d37b228646805df1c89 $")
