@@ -1,10 +1,10 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 20566c6386c58b1fe4a199f96fe0543e135aee94 $
+// $Id: 45615b289fdc1b78fffc5d56f4145b44d0476938 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -1171,13 +1171,13 @@ void A_WeaponMeleeAttack(AActor* mo)
 //
 void A_WeaponSound(AActor *mo)
 {
-	player_t* player = mo->player;
-	struct pspdef_s* psp = &player->psprites[player->psprnum];
+	const player_t* player = mo->player;
+	const pspdef_s* psp = &player->psprites[player->psprnum];
 
 	if (!psp->state)
 		return;
 
-	int sndmap = psp->state->args[0];
+	const int sndmap = psp->state->args[0];
 	const char* snd;
 
 	auto soundIt = SoundMap.find(sndmap);
@@ -1667,4 +1667,4 @@ FArchive &operator>> (FArchive &arc, pspdef_t &def)
 	return arc >> def.state >> def.tics >> def.sx >> def.sy;
 }
 
-VERSION_CONTROL (p_pspr_cpp, "$Id: 20566c6386c58b1fe4a199f96fe0543e135aee94 $")
+VERSION_CONTROL (p_pspr_cpp, "$Id: 45615b289fdc1b78fffc5d56f4145b44d0476938 $")
