@@ -1,10 +1,10 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: d6d5e4606f2862451e0570a79455d47c6413f9dc $
+// $Id: ce0808f91f3047ae1bbc56508481fc10b8371703 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -967,7 +967,7 @@ bool P_CheckSightEdges(const AActor* t1, const AActor* t2, float radius_boost)
 //
 // Adapted from Eternity, so big thanks to Quasar
 //
-bool P_CheckFov(AActor* t1, AActor* t2, angle_t fov)
+bool P_CheckFov(const AActor* t1, const AActor* t2, angle_t fov)
 {
 	angle_t angle, minang, maxang;
 
@@ -979,4 +979,4 @@ bool P_CheckFov(AActor* t1, AActor* t2, angle_t fov)
 	                          : angle >= minang && angle <= maxang);
 }
 
-VERSION_CONTROL (p_sight_cpp, "$Id: d6d5e4606f2862451e0570a79455d47c6413f9dc $")
+VERSION_CONTROL (p_sight_cpp, "$Id: ce0808f91f3047ae1bbc56508481fc10b8371703 $")
