@@ -2,10 +2,10 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 5407090b120dc0ac9445c881e02a312b0bdc3b46 $
+// $Id: 6282c8844fef00d6f855153db0058a3d92b51b56 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -79,7 +79,7 @@ std::list<sector_t*> specialdoors;
 bool s_SpecialFromServer;
 
 int P_FindSectorFromLineTag(int tag, int start);
-bool EV_DoDoor(DDoor::EVlDoor type, line_t* line, AActor* thing, int tag, int speed,
+bool EV_DoDoor(DDoor::EVlDoor type, line_t* line, const AActor* thing, int tag, int speed,
                int delay, card_t lock);
 bool P_ShootCompatibleSpecialLine(AActor* thing, line_t* line);
 bool P_ActivateZDoomLine(line_t* line, AActor* mo, int side,
@@ -196,7 +196,7 @@ int P_ArgToCrush(byte arg)
  * Returns nonzero if the object is under damage based on
  * their current position.
  */
-int P_IsUnderDamage(AActor* actor)
+int P_IsUnderDamage(const AActor* actor)
 {
 	const struct msecnode_s* seclist;
 	const DCeiling* cr; // Crushing ceiling
@@ -219,7 +219,7 @@ int P_IsUnderDamage(AActor* actor)
 * @param actor - Source actor
 * @param friendshiptest - Thing to test friendliness
 */
-bool P_IsFriendlyThing(AActor* actor, AActor* friendshiptest)
+bool P_IsFriendlyThing(const AActor* actor, const AActor* friendshiptest)
 {
 	if (!actor || !friendshiptest)
 	{
@@ -3204,4 +3204,4 @@ bool A_TriggerAction(AActor *mo, AActor *triggerer, int activationType) {
 	return trigger_action;
 }
 
-VERSION_CONTROL (p_spec_cpp, "$Id: 5407090b120dc0ac9445c881e02a312b0bdc3b46 $")
+VERSION_CONTROL (p_spec_cpp, "$Id: 6282c8844fef00d6f855153db0058a3d92b51b56 $")
