@@ -1,10 +1,10 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: c57359b2a2590cd86dceae63fe1c7ea70ca3d15b $
+// $Id: b49087793ebeb20343290aa512993925d1b64524 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -609,8 +609,8 @@ void	P_InitSwitchList ();
 
 void	P_ProcessSwitchDef ();
 
-short P_GetButtonTexture(line_t* line);
-bool	P_GetButtonInfo (line_t *line, unsigned &state, unsigned &time);
+short P_GetButtonTexture(const line_t* line);
+bool	P_GetButtonInfo (const line_t *line, unsigned &state, unsigned &time);
 bool	P_SetButtonInfo (line_t *line, unsigned state, unsigned time);
 
 void	P_UpdateButtons (client_t *cl);
@@ -868,7 +868,7 @@ public:
 	int			m_LightTag; // ZDoom compat
 
 protected:
-	friend bool	EV_DoDoor (DDoor::EVlDoor type, line_t *line, AActor *thing,
+	friend bool	EV_DoDoor (DDoor::EVlDoor type, line_t *line, const AActor *thing,
                                    int tag, int speed, int delay, card_t lock);
     friend bool EV_DoZDoomDoor(DDoor::EVlDoor type, line_t* line, AActor* mo, byte tag,
 	                         byte speed_byte, int topwait, zdoom_lock_t lock,
