@@ -1,10 +1,10 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: a1873a040c2543769ae80eff0df4df9a5f3f9f7d $
+// $Id: d6a6370f338e3c6d905a9e62a80e07f8479b9968 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -154,7 +154,7 @@ static void P_StartButton (line_t *line, DActiveButton::EWhere w, int texture,
 	new DActiveButton (line, w, texture, time, x, y);
 }
 
-short* P_GetButtonTexturePtr(line_t* line, short*& altTexture, DActiveButton::EWhere& where)
+short* P_GetButtonTexturePtr(const line_t* line, short*& altTexture, DActiveButton::EWhere& where)
 {
 	if (!line->sidenum[0])
 		return NULL;
@@ -190,7 +190,7 @@ short* P_GetButtonTexturePtr(line_t* line, short*& altTexture, DActiveButton::EW
 	return NULL;
 }
 
-short P_GetButtonTexture(line_t* line)
+short P_GetButtonTexture(const line_t* line)
 {
 	DActiveButton::EWhere twhere;
 	short* alt;
@@ -216,7 +216,7 @@ void P_SetButtonTexture(line_t* line, short texture)
 }
 
 // denis - query button
-bool P_GetButtonInfo (line_t *line, unsigned &state, unsigned &time)
+bool P_GetButtonInfo (const line_t *line, unsigned &state, unsigned &time)
 {
 	DActiveButton *button;
 	TThinkerIterator<DActiveButton> iterator;
@@ -422,4 +422,4 @@ void DActiveButton::RunThink ()
 	}
 }
 
-VERSION_CONTROL (p_switch_cpp, "$Id: a1873a040c2543769ae80eff0df4df9a5f3f9f7d $")
+VERSION_CONTROL (p_switch_cpp, "$Id: d6a6370f338e3c6d905a9e62a80e07f8479b9968 $")
