@@ -1,10 +1,10 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 414a6a488ba87fe57dd1d5140b64621379724581 $
+// $Id: 55f333dbed86a46c7154b7a9b0ed4a59e364ea84 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -43,7 +43,7 @@
 #ifdef _UNLAG_DEBUG_
 #include <list>
 void SV_SpawnMobj(AActor *mo);
-void SV_SendDestroyActor(AActor *mo);
+void SV_SendDestroyActor(const AActor *mo);
 #endif	// _UNLAG_DEBUG_
 
 EXTERN_CVAR(sv_maxunlagtime)
