@@ -1,10 +1,10 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: fd68101e9cff1f8a00925312200eacd7a895ece9 $
+// $Id: 637595d061f450e52facedb6b9b730dc31ad474b $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -701,7 +701,7 @@ struct vissprite_s
 	fixed_t			translucency;
 	byte			FakeFlat;		// [RH] which side of fake/floor ceiling sprite is on
 
-	AActor*			mo;
+	const AActor*			mo;
 };
 typedef vissprite_s vissprite_t;
 
@@ -769,7 +769,7 @@ struct visplane_s
 	shaderef_t	colormap;			// [RH] Support multiple colormaps
 	fixed_t		xscale, yscale;		// [RH] Support flat scaling
 	angle_t		angle;				// [RH] Support flat rotation
-	AActor::AActorPtr skybox;
+	AActor*		skybox;
 
 	unsigned int *bottom;			// [RH] bottom and top arrays are dynamically
 	unsigned int pad;				//		allocated immediately after the
