@@ -1,10 +1,10 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 187e7ed23121ea93d302f50889ee8d4441ada1ec $
+// $Id: 1a2dc4d15181ba85733c583f1c8124d912fe3877 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -739,22 +739,22 @@ void SN_StartSequence (polyobj_t *poly, const char *name)
 //
 //==========================================================================
 
-void SN_StopSequence (AActor *actor)
+void SN_StopSequence (const AActor *actor)
 {
 	SN_DoStop (actor);
 }
 
-void SN_StopSequence (sector_t *sector)
+void SN_StopSequence (const sector_t *sector)
 {
 	SN_DoStop (sector);
 }
 
-void SN_StopSequence (polyobj_t *poly)
+void SN_StopSequence (const polyobj_t *poly)
 {
 	SN_DoStop (poly);
 }
 
-void SN_DoStop (void *source)
+void SN_DoStop (const void *source)
 {
 	DSeqNode *node;
 
@@ -960,4 +960,4 @@ void DSeqNode::ChangeData (int seqOffset, int delayTics, float volume, int curre
 	m_CurrentSoundID = currentSoundID;
 }
 
-VERSION_CONTROL (s_sndseq_cpp, "$Id: 187e7ed23121ea93d302f50889ee8d4441ada1ec $")
+VERSION_CONTROL (s_sndseq_cpp, "$Id: 1a2dc4d15181ba85733c583f1c8124d912fe3877 $")
