@@ -261,12 +261,12 @@ int Fl_Menu_Item::measure(int* hp, const Fl_Menu_* m) const {
   l.font    = labelsize_ || labelfont_ ? labelfont_ : (m ? m->textfont() : FL_HELVETICA);
   l.size    = labelsize_ ? labelsize_ : m ? m->textsize() : FL_NORMAL_SIZE;
   l.color   = FL_FOREGROUND_COLOR; // this makes no difference?
-  l.spacing = 0;
+  l.h_margin_ = l.v_margin_ = l.spacing = 0;
   fl_draw_shortcut = 1;
   int w = 0; int h = 0;
   l.measure(w, hp ? *hp : h);
   fl_draw_shortcut = 0;
-  if (flags & (FL_MENU_TOGGLE|FL_MENU_RADIO)) w += FL_NORMAL_SIZE;
+  if (flags & (FL_MENU_TOGGLE|FL_MENU_RADIO)) w += FL_NORMAL_SIZE + 4;
   return w;
 }
 
@@ -281,7 +281,7 @@ void Fl_Menu_Item::draw(int x, int y, int w, int h, const Fl_Menu_* m,
   l.font    = labelsize_ || labelfont_ ? labelfont_ : (m ? m->textfont() : FL_HELVETICA);
   l.size    = labelsize_ ? labelsize_ : m ? m->textsize() : FL_NORMAL_SIZE;
   l.color   = labelcolor_ ? labelcolor_ : m ? m->textcolor() : int(FL_FOREGROUND_COLOR);
-  l.spacing = 0;
+  l.h_margin_ = l.v_margin_ = l.spacing = 0;
   if (!active()) l.color = fl_inactive((Fl_Color)l.color);
   if (selected) {
     Fl_Color r = m ? m->selection_color() : FL_SELECTION_COLOR;
@@ -493,8 +493,11 @@ void menuwindow::autoscroll(int n) {
 
   int xx, ww;
   Fl_Window_Driver::driver(this)->menu_window_area(xx, scr_y, ww, scr_h);
-  if (Y <= scr_y) Y = scr_y-Y+10;
-  else {
+  if (n==0 && Y <= scr_y + itemheight) {
+    Y = scr_y - Y + 10;
+  } else if (Y <= scr_y + itemheight) {
+    Y = scr_y - Y + 10 + itemheight;
+  } else {
     Y = Y+itemheight-scr_h-scr_y;
     if (Y < 0) return;
     Y = -Y-10;
@@ -695,38 +698,44 @@ static void setitem(int m, int n) {
 }
 
 static int forward(int menu) { // go to next item in menu menu if possible
-  menustate &pp = *p;
-  // Fl_Menu_Button can generate menu=-1. This line fixes it and selects the first item.
-  if (menu==-1)
+  // `menu` is -1 if no item is currently selected, so use the first menu
+  if (menu < 0)
     menu = 0;
+  menustate &pp = *p;
   menuwindow &m = *(pp.p[menu]);
   int item = (menu == pp.menu_number) ? pp.item_number : m.selected;
+  bool wrapped = false;
   do {
     while (++item < m.numitems) {
       const Fl_Menu_Item* m1 = m.menu->next(item);
       if (m1->activevisible()) {setitem(m1, menu, item); return 1;}
     }
+    if (wrapped) break;
     item = -1;
+    wrapped = true;
   }
-  while (pp.menubar && Fl::event_key() == FL_Right);
+  while (Fl::event_key() != FL_Down);
   return 0;
 }
 
 static int backward(int menu) { // previous item in menu menu if possible
-  // `menu` is -1 if no item is currently selected, we return 0
-  if (menu<0)
-    return 0;
+  // `menu` is -1 if no item is currently selected, so use the first menu
+  if (menu < 0)
+    menu = 0;
   menustate &pp = *p;
   menuwindow &m = *(pp.p[menu]);
   int item = (menu == pp.menu_number) ? pp.item_number : m.selected;
+  bool wrapped = false;
   do {
     while (--item >= 0) {
       const Fl_Menu_Item* m1 = m.menu->next(item);
       if (m1->activevisible()) {setitem(m1, menu, item); return 1;}
     }
+    if (wrapped) break;
     item = m.numitems;
+    wrapped = true;
   }
-  while (pp.menubar && Fl::event_key() == FL_Left);
+  while (Fl::event_key() != FL_Up);
   return 0;
 }
 
@@ -794,10 +803,7 @@ int menuwindow::handle_part1(int e) {
     switch (Fl::event_key()) {
     case FL_BackSpace:
     BACKTAB:
-      if (!backward(pp.menu_number)) {
-        pp.item_number = -1;
-        backward(pp.menu_number);
-      }
+      backward(pp.menu_number);
       return 1;
     case FL_Up:
       if (pp.menubar && pp.menu_number == 0) {
@@ -810,17 +816,16 @@ int menuwindow::handle_part1(int e) {
       return 1;
     case FL_Tab:
       if (Fl::event_shift()) goto BACKTAB;
+      if (pp.menubar && pp.menu_number == 0) goto RIGHT;
     case FL_Down:
       if (pp.menu_number || !pp.menubar) {
-        if (!forward(pp.menu_number) && Fl::event_key()==FL_Tab) {
-          pp.item_number = -1;
-          forward(pp.menu_number);
-        }
+        forward(pp.menu_number);
       } else if (pp.menu_number < pp.nummenus-1) {
         forward(pp.menu_number+1);
       }
       return 1;
     case FL_Right:
+    RIGHT:
       if (pp.menubar && (pp.menu_number<=0 || (pp.menu_number == pp.nummenus-1)))
         forward(0);
       else if (pp.menu_number < pp.nummenus-1) forward(pp.menu_number+1);
@@ -833,6 +838,20 @@ int menuwindow::handle_part1(int e) {
     case FL_Enter:
     case FL_KP_Enter:
     case ' ':
+      // if the current item is a submenu with no callback,
+      // simulate FL_Right to enter the submenu
+      if (   pp.current_item
+          && (!pp.menubar || pp.menu_number > 0)
+          && pp.current_item->activevisible()
+          && pp.current_item->submenu()
+          && !pp.current_item->callback_)
+      {
+        goto RIGHT;
+      }
+      // Ignore keypresses over inactive items, mark KEYBOARD event as used.
+      if (pp.current_item && !pp.current_item->activevisible())
+        return 1;
+      // Mark the menu 'done' which will trigger the callback
       pp.state = DONE_STATE;
       return 1;
     case FL_Escape:
@@ -896,8 +915,7 @@ int menuwindow::handle_part1(int e) {
           return 0;
         }
       }
-      if (my == 0 && item > 0) setitem(mymenu, item - 1);
-      else setitem(mymenu, item);
+      setitem(mymenu, item);
       if (e == FL_PUSH) {
         if (pp.current_item && pp.current_item->submenu() // this is a menu title
             && item != pp.p[mymenu]->selected // and it is not already on
@@ -922,8 +940,9 @@ int menuwindow::handle_part1(int e) {
         pp.p[pp.menu_number]->redraw();
       } else
 #endif
-      // do nothing if they try to pick inactive items
-      if (!pp.current_item || pp.current_item->activevisible())
+      // do nothing if they try to pick an inactive item, or a submenu with no callback
+      if (!pp.current_item || (pp.current_item->activevisible() &&
+         (!pp.current_item->submenu() || pp.current_item->callback_ || (pp.menubar && pp.menu_number <= 0))))
         pp.state = DONE_STATE;
     }
     return 1;
@@ -998,7 +1017,13 @@ const Fl_Menu_Item* Fl_Menu_Item::pulldown(
     }
   }
   initial_item = pp.current_item;
-  if (initial_item) goto STARTUP;
+  if (initial_item) {
+    if (menubar && !initial_item->activevisible()) { // pointing at inactive item
+      Fl::grab(0);
+      return NULL;
+    }
+    goto STARTUP;
+  }
 
   // the main loop: runs until p.state goes to DONE_STATE or the menu
   // widget is deleted (e.g. from a timer callback, see STR #3503):
