@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2020-2020 Martin Moene
+// Copyright (c) 2020-2025 Martin Moene
 //
 // https://github.com/martinmoene/bit-lite
 //
@@ -9,8 +9,8 @@
 #ifndef NONSTD_BIT_LITE_HPP
 #define NONSTD_BIT_LITE_HPP
 
-#define bit_lite_MAJOR  0
-#define bit_lite_MINOR  1
+#define bit_lite_MAJOR  1
+#define bit_lite_MINOR  2
 #define bit_lite_PATCH  0
 
 #define bit_lite_VERSION  bit_STRINGIFY(bit_lite_MAJOR) "." bit_STRINGIFY(bit_lite_MINOR) "." bit_STRINGIFY(bit_lite_PATCH)
@@ -32,7 +32,7 @@
 # define bit_CONFIG_STRICT  0
 #endif
 
-// C++ language version detection (C++20 is speculative):
+// C++ language version detection (C++23 is speculative):
 // Note: VC14.0/1900 (VS2015) lacks too much from C++14.
 
 #ifndef   bit_CPLUSPLUS
@@ -47,7 +47,8 @@
 #define bit_CPP11_OR_GREATER  ( bit_CPLUSPLUS >= 201103L )
 #define bit_CPP14_OR_GREATER  ( bit_CPLUSPLUS >= 201402L )
 #define bit_CPP17_OR_GREATER  ( bit_CPLUSPLUS >= 201703L )
-#define bit_CPP20_OR_GREATER  ( bit_CPLUSPLUS >= 202000L )
+#define bit_CPP20_OR_GREATER  ( bit_CPLUSPLUS >= 202002L )
+#define bit_CPP23_OR_GREATER  ( bit_CPLUSPLUS >= 202300L )
 
 // Use C++20 std bit operations if available and requested:
 
@@ -71,6 +72,13 @@
 
 #include <bit>
 
+#if bit_CPP20_OR_GREATER
+# include <version>
+# define bit_HAVE_BYTESWAP  __cpp_lib_byteswap
+#else
+# define bit_HAVE_BYTESWAP  0
+#endif
+
 namespace nonstd
 {
     using std::bit_cast;
@@ -89,6 +97,10 @@ namespace nonstd
     using std::countr_one;
     using std::popcount;
 
+#if bit_HAVE_BYTESWAP || bit_CPP23_OR_GREATER
+    using std::byteswap;
+#endif
+
     using std::endian;
 }
 
@@ -209,6 +221,10 @@ namespace nonstd
 
 #define bit_HAVE_NODISCARD              bit_CPP17_000
 
+// Presence of C++23 library features:
+
+#define bit_HAVE_BYTESWAP               1  // self-supplied
+
 // Presence of C++ language features:
 
 #if bit_HAVE_CONSTEXPR_11
@@ -247,6 +263,21 @@ namespace nonstd
 # include <tr1/type_traits>
 #endif
 
+#ifdef  _MSC_VER
+# include <cstdlib>
+# define bit_byteswap16  _byteswap_ushort
+# define bit_byteswap32  _byteswap_ulong
+# define bit_byteswap64  _byteswap_uint64
+#else
+# define bit_byteswap16  __builtin_bswap16
+# define bit_byteswap32  __builtin_bswap32
+# define bit_byteswap64  __builtin_bswap64
+#endif
+
+#if bit_HAVE( CSTDINT )
+# include <cstdint>
+#endif
+
 // Method enabling (return type):
 
 #if bit_HAVE( TYPE_TRAITS )
@@ -255,7 +286,7 @@ namespace nonstd
 # define bit_ENABLE_IF_R_(R, VA)  R
 #endif
 
-// Method enabling (funtion template argument):
+// Method enabling (function template argument):
 
 #if bit_HAVE( TYPE_TRAITS ) && bit_HAVE( DEFAULT_FUNCTION_TEMPLATE_ARG )
 // VS 2013 seems to have trouble with SFINAE for default non-type arguments:
@@ -289,6 +320,20 @@ bit_constexpr T bitmask( int i )
 
 namespace std11 {
 
+#if bit_HAVE( CSTDINT )
+    using std::uint8_t;
+    using std::uint16_t;
+    using std::uint32_t;
+    using std::uint64_t;
+#else
+    typedef unsigned char      uint8_t;
+    typedef unsigned short int uint16_t;
+    typedef unsigned int       uint32_t;
+# if bit_CPP11_OR_GREATER
+    typedef unsigned long long uint64_t;
+# endif
+#endif
+
 template< class T, T v > struct integral_constant { enum { value = v }; };
 typedef integral_constant< bool, true  > true_type;
 typedef integral_constant< bool, false > false_type;
@@ -331,7 +376,7 @@ typedef integral_constant< bool, false > false_type;
     template< class T, class U > struct is_same : std11::true_type{};
 #endif
 
-} // namepsace std11
+} // namespace std11
 
 // C++20 emulation:
 
@@ -340,7 +385,32 @@ namespace std20 {
 template< class T, class U >
 struct same_as : std11::integral_constant<bool, std11::is_same<T,U>::value && std11::is_same<U,T>::value> {};
 
-} // namepsace std20
+} // namespace std20
+
+// Other detail:
+
+// make sure all unsigned types are covered, see
+// http://ithare.com/c-on-using-int_t-as-overload-and-template-parameters/
+
+template< size_t N > struct uint_by_size;
+template<> struct uint_by_size< 8> { typedef std11::uint8_t  type; };
+template<> struct uint_by_size<16> { typedef std11::uint16_t type; };
+template<> struct uint_by_size<32> { typedef std11::uint32_t type; };
+#if bit_CPP11_OR_GREATER
+template<> struct uint_by_size<64> { typedef std11::uint64_t type; };
+#endif
+
+template< typename T >
+struct normalized_uint_type
+{
+    typedef typename uint_by_size< CHAR_BIT * sizeof( T ) >::type type;
+
+#if bit_HAVE( STATIC_ASSERT )
+    static_assert( std::is_integral<T>::value, "integral type required.");
+    static_assert( std11::is_unsigned<type>::value, "unsigned type result expected.");
+    static_assert( sizeof( type ) == sizeof( T ), "size of determined type differs from type derived from.");
+#endif
+};
 
 //
 // For reference:
@@ -352,19 +422,22 @@ struct same_as : std11::integral_constant<bool, std11::is_same<T,U>::value && st
 
 template< class To, class From > constexpr To bit_cast( From const & from ) noexcept;
 
-// 26.5.4, integral powers of 2
+// 26.5.4, byteswap
+template< class T > constexpr T byteswap(T value) noexcept;
+
+// 26.5.5, integral powers of 2
 
 template< class T > constexpr bool has_single_bit(T x) noexcept;
 template< class T > constexpr T bit_ceil(T x);
 template< class T > constexpr T bit_floor(T x) noexcept;
 template< class T > constexpr T bit_width(T x) noexcept;
 
-// 26.5.5, rotating
+// 26.5.6, rotating
 
 template< class T > [[nodiscard]] constexpr T rotl(T x, int s) noexcept;
 template< class T > [[nodiscard]] constexpr T rotr(T x, int s) noexcept;
 
-// 26.5.6, counting
+// 26.5.7, counting
 
 template< class T > constexpr int countl_zero(T x) noexcept;
 template< class T > constexpr int countl_one(T x) noexcept;
@@ -399,7 +472,39 @@ bit_cast( From const & src ) bit_noexcept
     return dst;
 }
 
-// 26.5.5, rotating
+// 26.5.4, byteswap (C++23, p1272)
+
+inline bit_constexpr std11::uint8_t byteswap_( std11::uint8_t value ) bit_noexcept
+{
+    return value;
+}
+
+inline /*bit_constexpr*/ std11::uint16_t byteswap_( std11::uint16_t value ) bit_noexcept
+{
+    return bit_byteswap16( value );
+}
+
+inline /*bit_constexpr*/ std11::uint32_t byteswap_( std11::uint32_t value ) bit_noexcept
+{
+    return bit_byteswap32( value );
+}
+
+#if bit_CPP11_OR_GREATER
+
+inline /*bit_constexpr*/ std11::uint64_t byteswap_( std11::uint64_t value ) bit_noexcept
+{
+    return bit_byteswap64( value );
+}
+
+#endif
+
+template< typename T >
+inline /*bit_constexpr*/ T byteswap( T v ) bit_noexcept
+{
+    return static_cast<T>( byteswap_( static_cast< typename normalized_uint_type<T>::type >( v ) ) );
+}
+
+// 26.5.6, rotating
 
 // clang 3.5 - 3.8: Infinite recursive template instantiation when using Clang while GCC works fine?
 // https://stackoverflow.com/questions/37931284/infinite-recursive-template-instantiation-when-using-clang-while-gcc-works-fine
@@ -461,7 +566,7 @@ bit_nodiscard bit_constexpr14 T rotr(T x, int s) bit_noexcept
     return rotr_impl( x, s );
 }
 
-// 26.5.6, counting
+// 26.5.7, counting
 
 template< class T
     bit_ENABLE_IF_(
@@ -553,7 +658,7 @@ bit_constexpr14 int popcount(T x) bit_noexcept
     return result;
 }
 
-// 26.5.4, integral powers of 2
+// 26.5.5, integral powers of 2
 
 template< class T
     bit_ENABLE_IF_(
@@ -632,7 +737,7 @@ bit_constexpr T bit_floor(T x) bit_noexcept
         : 0;
 }
 
-// 26.5.7, endian
+// 26.5.8, endian
 
 #if bit_HAVE( ENUM_CLASS )
 
@@ -688,21 +793,6 @@ private:
 
 #if !bit_CONFIG_STRICT
 
-#ifdef  _MSC_VER
-# include <cstdlib>
-# define bit_byteswap16  _byteswap_ushort
-# define bit_byteswap32  _byteswap_ulong
-# define bit_byteswap64  _byteswap_uint64
-#else
-# define bit_byteswap16  __builtin_bswap16
-# define bit_byteswap32  __builtin_bswap32
-# define bit_byteswap64  __builtin_bswap64
-#endif
-
-#if bit_HAVE( CSTDINT )
-# include <cstdint>
-#endif
-
 namespace nonstd {
 namespace bit {
 
@@ -712,94 +802,66 @@ typedef std11::integral_constant<int, static_cast<int>(endian::big   )> big_endi
 typedef std11::integral_constant<int, static_cast<int>(endian::little)> little_endian_type;
 typedef std11::integral_constant<int, static_cast<int>(endian::native)> native_endian_type;
 
-// make sure all unsigned types are covered, see
-// http://ithare.com/c-on-using-int_t-as-overload-and-template-parameters/
-
-namespace std11 {
-
-#if bit_HAVE( CSTDINT )
-    using std::uint8_t;
-    using std::uint16_t;
-    using std::uint32_t;
-    using std::uint64_t;
-#else
-    typedef unsigned char      uint8_t;
-    typedef unsigned short int uint16_t;
-    typedef unsigned int       uint32_t;
-    typedef unsigned long long uint64_t;
-#endif
-} // namespace std11
-
-template< size_t N > struct uint_by_size;
-template<> struct uint_by_size< 8> { typedef std11::uint8_t  type; };
-template<> struct uint_by_size<16> { typedef std11::uint16_t type; };
-template<> struct uint_by_size<32> { typedef std11::uint32_t type; };
-template<> struct uint_by_size<64> { typedef std11::uint64_t type; };
-
-template< typename T >
-struct normalized_uint_type
-{
-    typedef typename uint_by_size< CHAR_BIT * sizeof( T ) >::type type;
-
-#if bit_HAVE( STATIC_ASSERT )
-    static_assert( sizeof( type ) == sizeof( T ), "");
-    static_assert( std::is_integral<T>::value, "");
-    static_assert( std11::is_unsigned<type>::value, "");
-#endif
-};
-
 // to big endian (implementation):
 
-inline std11::uint8_t to_big_endian_( std11::uint8_t v, little_endian_type )
+inline std11::uint8_t to_big_endian_( std11::uint8_t v, little_endian_type ) bit_noexcept
 {
     return v;
 }
 
-inline std11::uint16_t to_big_endian_( std11::uint16_t v, little_endian_type )
+inline std11::uint16_t to_big_endian_( std11::uint16_t v, little_endian_type ) bit_noexcept
 {
     return bit_byteswap16( v );
 }
 
-inline std11::uint32_t to_big_endian_( std11::uint32_t v, little_endian_type )
+inline std11::uint32_t to_big_endian_( std11::uint32_t v, little_endian_type ) bit_noexcept
 {
     return bit_byteswap32( v );
 }
 
-inline std11::uint64_t to_big_endian_( std11::uint64_t v, little_endian_type )
+#if bit_CPP11_OR_GREATER
+
+inline std11::uint64_t to_big_endian_( std11::uint64_t v, little_endian_type ) bit_noexcept
 {
     return bit_byteswap64( v );
 }
 
+#endif
+
 template< typename T >
-inline T to_big_endian_( T v, big_endian_type )
+inline T to_big_endian_( T v, big_endian_type ) bit_noexcept
 {
     return v;
 }
 
 // to little endian (implementation):
 
-inline std11::uint8_t to_little_endian_( std11::uint8_t v, big_endian_type )
+inline std11::uint8_t to_little_endian_( std11::uint8_t v, big_endian_type ) bit_noexcept
 {
     return v;
 }
 
-inline std11::uint16_t to_little_endian_( std11::uint16_t v, big_endian_type )
+inline std11::uint16_t to_little_endian_( std11::uint16_t v, big_endian_type ) bit_noexcept
 {
     return bit_byteswap16( v );
 }
 
-inline std11::uint32_t to_little_endian_( std11::uint32_t v, big_endian_type )
+inline std11::uint32_t to_little_endian_( std11::uint32_t v, big_endian_type ) bit_noexcept
 {
     return bit_byteswap32( v );
 }
 
-inline std11::uint64_t to_little_endian_( std11::uint64_t v, big_endian_type )
+#if bit_CPP11_OR_GREATER
+
+inline std11::uint64_t to_little_endian_( std11::uint64_t v, big_endian_type ) bit_noexcept
 {
     return bit_byteswap64( v );
 }
 
+#endif
+
 template< typename T >
-inline T to_little_endian_( T v, little_endian_type )
+inline T to_little_endian_( T v, little_endian_type ) bit_noexcept
 {
     return v;
 }
@@ -807,13 +869,13 @@ inline T to_little_endian_( T v, little_endian_type )
 // to native endian (implementation):
 
 template< typename T >
-inline T to_native_endian_( T v, native_endian_type )
+inline T to_native_endian_( T v, native_endian_type ) bit_noexcept
 {
     return v;
 }
 
 template< typename T, typename EN >
-inline T to_native_endian_( T v, EN )
+inline T to_native_endian_( T v, EN ) bit_noexcept
 {
     // force conversion:
     return to_big_endian_( v, little_endian_type() );
@@ -825,37 +887,37 @@ inline T to_native_endian_( T v, EN )
 //
 
 template< typename T >
-inline T to_big_endian( T v )
+inline T to_big_endian( T v ) bit_noexcept
 {
     return to_big_endian_( static_cast< typename normalized_uint_type<T>::type >( v ), little_endian_type() );
 }
 
 template< typename T, typename EN >
-inline T to_big_endian( T v, EN )
+inline T to_big_endian( T v, EN ) bit_noexcept
 {
     return to_big_endian_( static_cast< typename normalized_uint_type<T>::type >( v ), EN() );
 }
 
 template< typename T >
-inline T to_little_endian( T v )
+inline T to_little_endian( T v ) bit_noexcept
 {
     return to_little_endian_( static_cast< typename normalized_uint_type<T>::type >( v ), big_endian_type() );
 }
 
 template< typename T, typename EN >
-inline T to_little_endian( T v, EN )
+inline T to_little_endian( T v, EN ) bit_noexcept
 {
     return to_little_endian_( static_cast< typename normalized_uint_type<T>::type >( v ), EN() );
 }
 
 template< typename T >
-inline T to_native_endian( T v )
+inline T to_native_endian( T v ) bit_noexcept
 {
     return to_native_endian_( static_cast< typename normalized_uint_type<T>::type >( v ), native_endian_type() );
 }
 
 template< typename T, typename EN >
-inline T to_native_endian( T v, EN )
+inline T to_native_endian( T v, EN ) bit_noexcept
 {
     return to_native_endian_( static_cast< typename normalized_uint_type<T>::type >( v ), EN() );
 }
@@ -865,19 +927,19 @@ inline T to_native_endian( T v, EN )
 //
 
 template< typename T >
-inline T as_big_endian( T v )
+inline T as_big_endian( T v ) bit_noexcept
 {
     return to_big_endian( v, native_endian_type() );
 }
 
 template< typename T >
-inline T as_little_endian( T v )
+inline T as_little_endian( T v ) bit_noexcept
 {
     return to_little_endian( v, native_endian_type() );
 }
 
 template< typename T >
-inline T as_native_endian( T v )
+inline T as_native_endian( T v ) bit_noexcept
 {
     return to_native_endian( v, native_endian_type() );
 }
@@ -908,6 +970,8 @@ namespace nonstd
     using bit::countr_one;
     using bit::popcount;
 
+    using bit::byteswap;
+
     using bit::endian;
 }
 
