@@ -1,11 +1,11 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 54fe86133351dee73bf0ffc28b866f74c3408742 $
+// $Id: 9917c2ead4c211c724212d16d707b9eb1892ec2f $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -403,7 +403,7 @@ void G_DoNewGame()
 	// [ML] 8/22/2010: There are examples in the wiki that outright don't work
 	// when onlcvars (addcommandstring's second param) is true.  Is there a
 	// reason why the mapscripts ahve to be safe mode?
-	if (strlen(sv_startmapscript.cstring()))
+	if (!sv_startmapscript.str().empty())
 		AddCommandString(sv_startmapscript.str());
 
 	G_InitNew (d_mapname);
@@ -1025,4 +1025,4 @@ void G_WorldDone (void)
 }
 
 
-VERSION_CONTROL (g_level_cpp, "$Id: 54fe86133351dee73bf0ffc28b866f74c3408742 $")
+VERSION_CONTROL (g_level_cpp, "$Id: 9917c2ead4c211c724212d16d707b9eb1892ec2f $")
