@@ -1,11 +1,11 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 4a82ab5648c6c8bdfa12bdca4581d714d382395a $
+// $Id: 098c0c8755e4cf1e40d4218918f30f8ca0c7a300 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom 1.22).
 // Copyright (C) 2000-2006 by Sergey Makovkin (CSDoom .62).
-// Copyright (C) 2006-2025 by The Odamex Team.
+// Copyright (C) 2006-2026 by The Odamex Team.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -42,8 +42,8 @@ argb_t V_GetColorFromString(const std::string& str)
     return 0;
 }
 
-void PickupMessage(AActor *toucher, const char *message) {}
-void WeaponPickupMessage(AActor *toucher, weapontype_t &Weapon) {}
+void PickupMessage(const AActor *toucher, const char *message) {}
+void WeaponPickupMessage(const AActor *toucher, const weapontype_t &Weapon) {}
 
 void AM_Stop(void) {}
 
@@ -53,4 +53,4 @@ void V_RefreshColormaps() {}
 
 CVAR_FUNC_IMPL (sv_allowwidescreen) {}
 
-VERSION_CONTROL (sv_stubs_cpp, "$Id: 4a82ab5648c6c8bdfa12bdca4581d714d382395a $")
+VERSION_CONTROL (sv_stubs_cpp, "$Id: 098c0c8755e4cf1e40d4218918f30f8ca0c7a300 $")
